# Security Policy

The latest version of pydantypes is supported.

## Reporting a Vulnerability

Please report security vulnerabilities via GitHub's private vulnerability reporting:
https://github.com/oborchers/pydantypes/security/advisories/new

Do not open public issues for security vulnerabilities.
